package product;

/**
 * An encapsulation of an ElectricTeethbrush.
 * 
 * @author CS159 Professors, James Madison University
 * @version 1
 */
public class ElectricTeethbrush extends Teethbrush {

    private static final double BASE_BODY_COST = 5.00;
    private static final double RECHARGEABLE_UPCHARGE = 20.00;
    private static final double ULTRASONIC_UPCHARGE = 10.00;
    private static final int NUMBER_OF_HEADS = 5;

    private boolean rechargeable, ultrasonic;

    /**
     * Explicit Value Constructor.
     * 
     * @param model The model
     * @param hardness The hardness of the bristles
     * @param polished true of the bristles are polished; false otherwise
     * @param rechargeable true if the battery is rechargeable; false otherwise
     * @param ultrasonic true if its is ultrasonic; false otherwise
     */
    public ElectricTeethbrush(String model, int hardness, boolean polished,
            boolean rechargeable, boolean ultrasonic) {

        super(model, hardness, polished);
        this.rechargeable = rechargeable;
        this.ultrasonic = ultrasonic;
    }

    /**
     * Get the cost of this Teethbrush.
     * 
     * @return The cost
     */
    @Override
    public double cost() {

        double result;
        result = super.cost() * NUMBER_OF_HEADS + BASE_BODY_COST;
        if (rechargeable) result += RECHARGEABLE_UPCHARGE;
        if (ultrasonic) result += ULTRASONIC_UPCHARGE;

        return result;
    }

    /**
     * Return true if this ElectricteethBrush is rechargeable; false otherwise.
     * 
     * @return true if the rechargeable; false otherwise.
     */
    public boolean isRechargeable() {
        return rechargeable;
    }

    /**
     * Return true if this ElectricteethBrush is ultrasonic; false otherwise.
     * 
     * @return true if the ultrasonic; false otherwise.
     */
    public boolean isUltrasonic() {
        return ultrasonic;
    }
}
