package product;

/**
 * An encapsulation of a Teethbrush.
 * 
 * @author CS159 Professors, James Madison University
 * @version 1
 */
public class Teethbrush {

    private static final double BASE_HEAD_COST = 2.00;
    private static final double HARDNESS_UPCHARGE = 0.10;
    private static final double LARGE_ORDER_DISCOUNT = 0.30;
    private static final double POLISHED_UPCHARGE = 0.75;
    private static final double STOCKING_COST = 25.00;
    private static final double UNIT_SHIPPING_COST_OVERSEAS = 0.30;
    private static final double UNIT_SHIPPING_COST_LOCAL = 0.10;

    private static final int LARGE_ORDER = 1000;

    private boolean polished;
    private int hardness, inventory;
    private String model;

    /**
     * Explicit Value Constructor.
     * 
     * @param model The model
     * @param hardness The hardness of the bristles
     * @param polished true of the bristles are polished; false otherwise
     */
    public Teethbrush(String model, int hardness, boolean polished) {

        this.model = model;
        setHardness(hardness);
        this.polished = polished;
    }

    /**
     * Adjust the size of the inventory for this Teethbrush.
     * 
     * Note that a change that would make the inventory negative is not possible
     * so no change will be made and this method will return false.
     * 
     * @param amount The amount of the change (positive or negative)
     * @return true if the inventory could be adjusted; false otherwise
     */
    public boolean changeInventory(int amount) {
        if ((inventory + amount) < 0) return false;

        inventory += amount;
        return true;
    }

    /**
     * Get the cost of this Teethbrush.
     * 
     * @return The cost
     */
    public double cost() {

        double result;

        result = BASE_HEAD_COST + (hardness * HARDNESS_UPCHARGE);
        if (polished) result += POLISHED_UPCHARGE;

        return result;
    }

    /**
     * Get the hardness of the bristles.
     * 
     * @return The hardness
     */
    public int getHardness() {
        return hardness;
    }

    /**
     * Get the inventory.
     * 
     * @return The inventory
     */
    public int getInventory() {
        return inventory;
    }

    /**
     * Get the model.
     * 
     * @return The model
     */
    public String getModel() {
        return model;
    }

    /**
     * * Return true if the bristles are polished; false otherwise.
     * 
     * @return true if polished; false otherwise.
     */
    public boolean isPolished() {
        return polished;
    }

    /**
     * Set the hardness of the bristles.
     * 
     * @param hardness The hardness
     */
    private void setHardness(int hardness) {
        if (hardness < 0) this.hardness = 0;
        else if (hardness > 5) this.hardness = 5;
        else this.hardness = hardness;
    }

    /**
     * Return the shipping cost for a particular order.
     * 
     * @param orderSize The size of the order
     * @param overseas true of the order is being shipped overseas
     * @return The shipping cost
     */
    public double shippingCost(int orderSize, boolean overseas) {

        double result, unitCost;

        if (overseas) unitCost = UNIT_SHIPPING_COST_OVERSEAS;
        else          unitCost = UNIT_SHIPPING_COST_LOCAL;

        if (orderSize > LARGE_ORDER)
            unitCost *= (1 - LARGE_ORDER_DISCOUNT);

        result = unitCost * orderSize;

        if (orderSize > inventory) result += STOCKING_COST;

        return result;
    }
}
