package product.io;

import java.io.*;
import java.util.*;
import product.*;

/**
 * A utility class that can be used to read/write Teethbrush and
 * ElectricTeethbrush information from/to the file system in
 * comma-separated-valued (CSV) format.
 * 
 * @author CS159 Professors, James Madison University
 * @version 1
 */
public class ProductFileProcessor {

    /**
     * Read a Teethbrush object.
     * 
     * @param model The model of the Teethbrush
     * @return An appropriately initialized Toothbrush object
     * @throws IOException If there is any problem.
     */
    public static Teethbrush readTeethbrush(String model) throws IOException {
        boolean polished;
        File from;
        int hardness, inventory;
        Scanner in;
        Teethbrush result;

        from = new File(model + ".bru");
        in = new Scanner(from);
        in.useDelimiter("[,\n]");
        inventory = in.nextInt();
        hardness = in.nextInt();
        polished = in.nextBoolean();
        in.nextLine(); // Consume the newline character

        in.close();

        result = new Teethbrush(model, hardness, polished);
        result.changeInventory(inventory);

        return result;
    }

    /**
     * Read an ElectricTeethbrush object.
     * 
     * @param model The model name
     * @return An appropriately initialized ElectricTeethbrush object
     * @throws IOException If there is any problem.
     */
    public static ElectricTeethbrush readElectricTeethbrush(String model)
            throws IOException {
        boolean polished, rechargeable, ultrasonic;
        ElectricTeethbrush result;
        File from;
        int hardness, inventory;
        Scanner in;

        from = new File(model + ".bru");
        in = new Scanner(from);
        in.useDelimiter("[,\n]");
        inventory = in.nextInt();
        hardness = in.nextInt();
        polished = in.nextBoolean();
        rechargeable = in.nextBoolean();
        ultrasonic = in.nextBoolean();
        in.nextLine(); // Consume the newline character

        in.close();

        result = new ElectricTeethbrush(model, hardness, polished, rechargeable,
                ultrasonic);
        result.changeInventory(inventory);

        return result;
    }

    /**
     * Write a CSV representation of a Teethbrush object to the file system.
     * 
     * @param product The Teethbrush object to write
     * @throws IOException If anything goes wrong
     */
    public static void writeTeethbrush(Teethbrush product) throws IOException {
        File to;
        PrintWriter out;

        to = new File(product.getModel() + ".bru");
        out = new PrintWriter(to);
        out.printf("%d,%d,%b\n", product.getInventory(), product.getHardness(),
                product.isPolished());
        out.close();
    }

    /**
     * Write a CSV representation of an ElectricTeethbrush to the file system.
     * 
     * @param product The ElectricTeethbrush object to write
     * @throws IOException If anything goes wrong
     */
    public static void writeElectricTeethbrush(ElectricTeethbrush product)
            throws IOException {
        File to;
        PrintWriter out;

        to = new File(product.getModel() + ".bru");
        out = new PrintWriter(to);
        out.printf("%d,%d,%b,%b,%b\n", product.getInventory(),
                product.getHardness(), product.isPolished(),
                product.isRechargeable(), product.isUltrasonic());
        out.close();
    }

}
