package testing;

import static org.junit.jupiter.api.Assertions.*;

import org.junit.jupiter.api.Test;
import product.ElectricTeethbrush;

class ElectricTeethbrushTest {

	private static final double TOL = 0.001;
	
	@Test
	void constructorAndGetters() {
		{
			ElectricTeethbrush t = new ElectricTeethbrush("E1000", 0, true, true, true);
			assertEquals("E1000", t.getModel());
			assertEquals(0, t.getHardness());
			assertTrue(t.isPolished());
			assertTrue(t.isRechargeable());
			assertTrue(t.isUltrasonic());
			assertEquals(0, t.getInventory());
		}
		{
			ElectricTeethbrush t = new ElectricTeethbrush("E1005", 5, false, false, false);
			assertEquals("E1005", t.getModel());
			assertEquals(5, t.getHardness());
			assertFalse(t.isPolished());
			assertFalse(t.isRechargeable());
			assertFalse(t.isUltrasonic());
			assertEquals(0, t.getInventory());
		}
		{
			ElectricTeethbrush t = new ElectricTeethbrush("E1000", 6, true, true, true);
			assertEquals("E1000", t.getModel());
			assertEquals(5, t.getHardness());
			assertTrue(t.isPolished());
			assertTrue(t.isRechargeable());
			assertTrue(t.isUltrasonic());
			assertEquals(0, t.getInventory());
		}
		{
			ElectricTeethbrush t = new ElectricTeethbrush("E1003", 3, true, false, true);
			assertEquals("E1003", t.getModel());
			assertEquals(3, t.getHardness());
			assertTrue(t.isPolished());
			assertFalse(t.isRechargeable());
			assertTrue(t.isUltrasonic());
			assertEquals(0, t.getInventory());
		}
        {
            ElectricTeethbrush t = new ElectricTeethbrush("E1010", -3, true, true, true);
            assertEquals("E1010", t.getModel());
            assertEquals(0, t.getHardness());
            assertTrue(t.isPolished());
            assertTrue(t.isRechargeable());
            assertTrue(t.isUltrasonic());
            assertEquals(0, t.getInventory());
        }
	}

	@Test
	void changeInventory() {
		{
			boolean done;
			ElectricTeethbrush t = new ElectricTeethbrush("E1000", 0, true, true, true);
			assertEquals("E1000", t.getModel());
			assertEquals(0, t.getInventory());

			done = t.changeInventory(-10);
			assertEquals(0, t.getInventory());
			assertFalse(done);
			
			done = t.changeInventory(135);
			assertEquals(135, t.getInventory());
			assertTrue(done);

			done = t.changeInventory(-10);
			assertEquals(125, t.getInventory());
			assertTrue(done);

			done = t.changeInventory(-626);
			assertEquals(125, t.getInventory());
			assertFalse(done);

			done = t.changeInventory(-125);
			assertEquals(0, t.getInventory());
			assertTrue(done);

			done = t.changeInventory(-10);
			assertEquals(0, t.getInventory());
			assertFalse(done);

			done = t.changeInventory(10);
			assertEquals(10, t.getInventory());
			assertTrue(done);
		}
	}

	
	@Test
	void cost() {
		{
			ElectricTeethbrush t = new ElectricTeethbrush("E2000", 0, false, false, false);
			assertEquals(15.00, t.cost(), TOL);
		}
		{
			ElectricTeethbrush t = new ElectricTeethbrush("E2001", 0, false, true, false);
			assertEquals(35.00, t.cost(), TOL);
		}
		{
			ElectricTeethbrush t = new ElectricTeethbrush("E2002", 0, false, true, true);
			assertEquals(45.00, t.cost(), TOL);
		}
		{
			ElectricTeethbrush t = new ElectricTeethbrush("E3000", 3, true, false, true);
			assertEquals(30.25, t.cost(), TOL);
		}
	}
	
	@Test
	void shippingCost() {
		ElectricTeethbrush t = new ElectricTeethbrush("E1000", 0, false, false, false);
		t.changeInventory(100);
		
		assertEquals(1*0.10, t.shippingCost(1, false), TOL);
		assertEquals(100*0.10, t.shippingCost(100, false), TOL);
		assertEquals(101*0.10 + 25.00, t.shippingCost(101, false), TOL);
		assertEquals(1000*0.10 + 25.00, t.shippingCost(1000, false), TOL);
		assertEquals(1001*0.07 + 25.00, t.shippingCost(1001, false), TOL);
		assertEquals(2000*0.07 + 25.00, t.shippingCost(2000, false), TOL);

		assertEquals(1*0.30, t.shippingCost(1, true), TOL);
		assertEquals(100*0.30, t.shippingCost(100, true), TOL);
		assertEquals(101*0.30 + 25.00, t.shippingCost(101, true), TOL);
		assertEquals(1000*0.30 + 25.00, t.shippingCost(1000, true), TOL);
		assertEquals(1001*0.21 + 25.00, t.shippingCost(1001, true), TOL);
		assertEquals(445.00, t.shippingCost(2000, true), TOL);
		
		
	}
}
