package testing;

import static org.junit.jupiter.api.Assertions.*;

import org.junit.jupiter.api.Test;
import product.Teethbrush;

class TeethbrushTest {

	private static final double TOL = 0.001;
	
	@Test
	void constructorAndGetters() {
		{
			Teethbrush t = new Teethbrush("M1000", 0, true);
			assertEquals("M1000", t.getModel());
			assertEquals(0, t.getHardness());
			assertTrue(t.isPolished());
			assertEquals(0, t.getInventory());
		}
		{
			Teethbrush t = new Teethbrush("M1005", 5, false);
			assertEquals("M1005", t.getModel());
			assertEquals(5, t.getHardness());
			assertFalse(t.isPolished());
			assertEquals(0, t.getInventory());
		}
		{
			Teethbrush t = new Teethbrush("M1000", -10, true);
			assertEquals("M1000", t.getModel());
			assertEquals(0, t.getHardness());
			assertTrue(t.isPolished());
			assertEquals(0, t.getInventory());
		}
		{
			Teethbrush t = new Teethbrush("M1005", 15, false);
			assertEquals("M1005", t.getModel());
			assertEquals(5, t.getHardness());
			assertFalse(t.isPolished());
			assertEquals(0, t.getInventory());
		}
	}

	@Test
	void changeInventory() {
		{
			boolean done;
			Teethbrush t = new Teethbrush("M1000", 0, true);
			assertEquals("M1000", t.getModel());
			assertEquals(0, t.getInventory());

			done = t.changeInventory(-10);
			assertEquals(0, t.getInventory());
			assertFalse(done);
			
			done = t.changeInventory(635);
			assertEquals(635, t.getInventory());
			assertTrue(done);

			done = t.changeInventory(-10);
			assertEquals(625, t.getInventory());
			assertTrue(done);

			done = t.changeInventory(-626);
			assertEquals(625, t.getInventory());
			assertFalse(done);

			done = t.changeInventory(-625);
			assertEquals(0, t.getInventory());
			assertTrue(done);

			done = t.changeInventory(-10);
			assertEquals(0, t.getInventory());
			assertFalse(done);
		}
	}

	
	@Test
	void cost() {
		{
			Teethbrush t = new Teethbrush("M1001", 0, false);
			assertEquals(2.00, t.cost(), TOL);
		}
		{
			Teethbrush t = new Teethbrush("M1000", 0, true);
			assertEquals(2.75, t.cost(), TOL);
		}
		{
			Teethbrush t = new Teethbrush("M1005", 5, false);
			assertEquals(2.50, t.cost(), TOL);
		}
		{
			Teethbrush t = new Teethbrush("M1006", 5, true);
			assertEquals(3.25, t.cost(), TOL);
		}
		{
			Teethbrush t = new Teethbrush("M1006", 10, true);
			assertEquals(3.25, t.cost(), TOL);
		}
	}
	
	@Test
	void shippingCost() {
		Teethbrush t = new Teethbrush("M1000", 0, true);
		t.changeInventory(100);
		
		assertEquals(1*0.10, t.shippingCost(1, false), TOL);
		assertEquals(100*0.10, t.shippingCost(100, false), TOL);
		assertEquals(101*0.10 + 25.00, t.shippingCost(101, false), TOL);
		assertEquals(1000*0.10 + 25.00, t.shippingCost(1000, false), TOL);
		assertEquals(1001*0.07 + 25.00, t.shippingCost(1001, false), TOL);
		assertEquals(2000*0.07 + 25.00, t.shippingCost(2000, false), TOL);

		assertEquals(1*0.30, t.shippingCost(1, true), TOL);
		assertEquals(100*0.30, t.shippingCost(100, true), TOL);
		assertEquals(101*0.30 + 25.00, t.shippingCost(101, true), TOL);
		assertEquals(1000*0.30 + 25.00, t.shippingCost(1000, true), TOL);
		assertEquals(1001*0.21 + 25.00, t.shippingCost(1001, true), TOL);
		assertEquals(445.00, t.shippingCost(2000, true), TOL);
		
		
	}
}
